@@ -6,7 +6,7 @@ import imp
 
 import wrapt
 
-from compat import PY2, PY3, exec_
+from compat import exec_, getfullargspec
 
 DECORATORS_CODE = """
 import wrapt
@@ -57,8 +57,8 @@ class TestNamingFunction(unittest.TestCase):
     def test_argspec(self):
         # Test preservation of function argument specification.
 
-        function1o_argspec = inspect.getargspec(function1o)
-        function1d_argspec = inspect.getargspec(function1d)
+        function1o_argspec = getfullargspec(function1o)
+        function1d_argspec = getfullargspec(function1d)
         self.assertEqual(function1o_argspec, function1d_argspec)
 
     def test_getmembers(self):
