@@ -6,7 +6,7 @@ import imp
 
 import wrapt
 
-from compat import PY2, PY3, exec_
+from compat import exec_, getfullargspec
 
 DECORATORS_CODE = """
 import wrapt
@@ -95,15 +95,15 @@ class TestNamingInstanceMethodOldStyle(unittest.TestCase):
     def test_class_argspec(self):
         # Test preservation of instance method argument specification.
 
-        original_argspec = inspect.getargspec(OldClass1o.function)
-        function_argspec = inspect.getargspec(OldClass1d.function)
+        original_argspec = getfullargspec(OldClass1o.function)
+        function_argspec = getfullargspec(OldClass1d.function)
         self.assertEqual(original_argspec, function_argspec)
 
     def test_instance_argspec(self):
         # Test preservation of instance method argument specification.
 
-        original_argspec = inspect.getargspec(OldClass1o().function)
-        function_argspec = inspect.getargspec(OldClass1d().function)
+        original_argspec = getfullargspec(OldClass1o().function)
+        function_argspec = getfullargspec(OldClass1d().function)
         self.assertEqual(original_argspec, function_argspec)
 
     def test_getmembers(self):
@@ -198,15 +198,15 @@ class TestNamingInstanceMethodNewStyle(unittest.TestCase):
     def test_class_argspec(self):
         # Test preservation of instance method argument specification.
 
-        original_argspec = inspect.getargspec(NewClass1o.function)
-        function_argspec = inspect.getargspec(NewClass1d.function)
+        original_argspec = getfullargspec(NewClass1o.function)
+        function_argspec = getfullargspec(NewClass1d.function)
         self.assertEqual(original_argspec, function_argspec)
 
     def test_instance_argspec(self):
         # Test preservation of instance method argument specification.
 
-        original_argspec = inspect.getargspec(NewClass1o().function)
-        function_argspec = inspect.getargspec(NewClass1d().function)
+        original_argspec = getfullargspec(NewClass1o().function)
+        function_argspec = getfullargspec(NewClass1d().function)
         self.assertEqual(original_argspec, function_argspec)
 
     def test_class_isinstance(self):
